.. _tuto:

Tutorials
=========

We show in these tutorials how to use the FFT classes. These classes are the basic
components of FluidFFT.  Note however that for most users, it's going to be
simpler to use directly the "operators" classes
:class:`fluidfft.fft2d.operators.OperatorsPseudoSpectral2D` and
:class:`fluidfft.fft3d.operators.OperatorsPseudoSpectral3D`.

.. toctree::
   :maxdepth: 1

   ipynb/tuto_fft2d_seq
   ipynb/executed/tuto_fft2d_mpi
   ipynb/executed/tuto_fft2d_mpi_domain_decomp
   ipynb/tuto_fft3d_seq
   ipynb/executed/tuto_fft3d_mpi
   ipynb/executed/tuto_fft3d_mpi_domain_decomp
